use Test::More tests => 1;

BEGIN {
use_ok( 'Catalyst::Action::RenderView::ErrorHandler' );
}

diag( "Testing Catalyst::Action::RenderView::ErrorHandler $Catalyst::Action::RenderView::ErrorHandler::VERSION" );
